.. rst-class:: detail

AbbClient
====================

.. currentmodule:: compas_rrc

.. autoclass:: AbbClient

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~AbbClient.__init__
        ~AbbClient.ensure_protocol_version
        ~AbbClient.feedback_callback
        ~AbbClient.send
        ~AbbClient.send_and_subscribe
        ~AbbClient.send_and_wait
        ~AbbClient.version_check
    
    